@@ -6,7 +6,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.0002_01'; # TRIAL VERSION
+our $VERSION = '0.0002_02'; # TRIAL VERSION
 
 use PDL::Core;
 use PDL::Lite;
@@ -32,7 +32,7 @@ sub pdl_ok {
     my ( $thing, $name ) = @_;
     my $ctx = context();
 
-    unless ( $thing->$_DOES('PDL') ) {
+    unless ( $thing->$_isa('PDL') ) {
         my $thingname = render_ref($thing);
         $ctx->ok( 0, $name, ["'$thingname' is not a piddle."] );
         $ctx->release;
@@ -111,7 +111,7 @@ sub pdl_is {
     # if ($got == $exp) has all ones, but that needs further generating
     # the diag message ourselves.
     my $is_numeric = !(
-        List::Util::any { $exp->$_DOES($_) }
+        List::Util::any { $exp->$_isa($_) }
             qw(PDL::SV PDL::Factor PDL::DateTime)
         or $exp->type eq 'byte'
     );
@@ -123,7 +123,7 @@ sub pdl_is {
     state $my_unpdl = sub {
         my ($x) = @_;
 
-        if ($x->$_DOES('PDL::DateTime')) {
+        if ($x->$_isa('PDL::DateTime')) {
             return $x->dt_unpdl();
         } else {
             return $x->unpdl;
@@ -225,7 +225,7 @@ Test2::Tools::PDL - Test2 tools for verifying Perl Data Language piddles
 
 =head1 VERSION
 
-version 0.0002_01
+version 0.0002_02
 
 =head1 SYNOPSIS
 
